@@ -18,6 +18,7 @@ from omfit_classes.omfit_nc import OMFITncData
 from omfit_classes.utils_base import printi
 from omfit_classes.exceptions_omfit import OMFITexception
 from omfit_classes.utils_math import interp1e
+from omfit_classes.utils_fusion import is_device
 
 import omas
 import numpy as np
@@ -71,6 +72,7 @@ class OMFITosborneProfile(OMFITmds):
     @treename.setter
     def treename(self, value):
         self.OMFITproperties['treename'] = value
+
     @property
     def time(self):
         return self.OMFITproperties['time']
@@ -278,6 +280,46 @@ class OMFITosborneProfile(OMFITmds):
             y = deriv(x, y)
         return x, y
 
+    def get_fit_params(self, fit, x_var='rhob', quant='ne', doc=False, covariance=True):
+        """
+        Get the parameters and their uncertainties
+
+        :param fit: Which type of fit to retrieve (tnh0 is the correct tanhfit for scalings)
+
+        :param x_var: The mapping of the fit (rhob,rhov,psi,R)
+
+        :param quant: The quantity that was fit
+
+        :param doc: (bool) if True print the fit documentation to understand which parameter is which
+
+        :param covariance: (bool) return the covariance matrix instead of just the errors
+
+        :return: params, cov -- tuple of parameters and their covariance matrix.
+                Errors are the sqrt of diagonals: np.sqrt(np.diag(cov))
+        """
+
+        node = self['%s%s%s' % (quant.upper(), fit.upper(), x_var.upper())]
+        if node.data() is None:
+            raise NoFitException('No fit for %s' % fit)
+
+        if doc:
+            print(f"Fit documentation for {quant.upper()}{fit.upper()}{x_var.upper()}")
+            print(node['FITDOC'].data()[0].format())
+
+        if covariance:
+            if 'FIT_COEFCOV' not in node:  # if the covariance matrix doesnt exist errors need to be in matrix
+                printi('Covariance matrix not available using listed errors for fit:%s' % fit)
+                params = node['FIT_COEF'].data()
+                cov = np.zeros((len(params), len(params)))
+                np.fill_diagnoal(cov, node['FIT_COEFERR'].data() ** 2)
+            else:
+                params, cov = node['FIT_COEF'].data(), node['FIT_COEFCOV'].data()
+        else:  # if covariance is False just return the errors
+            params = node['FIT_COEF'].data()
+            cov = node['FIT_COEFERR'].data()
+
+        return params, cov
+
     def plot_fit(self, fit, x_var='rhob', quant='ne', corr=True, nder=0, **kw):
         """
         Plot the fit for the given quant, with the given x-coordinate.
