@@ -703,7 +703,7 @@ def OMFITworkDir(root=None, server=''):
         locations = relativeLocations(root, dependencies=False)
         tmp = []
         for k in range(1, len(locations['OMFITmodulesName'])):
-            modName = parseLocation(locations['OMFITmodulesName'][k])[-1]
+            modName = parseLocation(locations['OMFITmodulesName'][k])[-1].replace(" ", "")
             runid = ''
             if locations['OMFITmodules'][k]['SETTINGS']['EXPERIMENT']['runid'] != None:
                 runid = '-' + str(locations['OMFITmodules'][k]['SETTINGS']['EXPERIMENT']['runid'])
