@@ -197,7 +197,10 @@ class OMFITtksValue():
         """
 
         data = self.data()
-        dims = ['dim_%d' % k for k in range(data.ndim)]
+        if self.is_dataset:
+            dims = list(self.record[self.shot][self.TDI].dims.keys())
+        else:
+            dims = list(self.record[self.shot][self.TDI]['dims'])
         clist=[]
         for k, c in enumerate(dims):
             clist.append(self.dim_of(k))
