@@ -44,6 +44,7 @@ __all__ = [
     'OMFITdataset',
     'pickle',
     'size_tree_objects',
+    'sorted_join_lists',
 ]
 
 # Useful patterns
@@ -146,6 +147,41 @@ def different(a, b, precision=0.0):
     return 0
 
 
+@_available_to_user_util
+def sorted_join_lists(a, b, favor_order_of_a=False, case_insensitive=False):
+    """
+    Join two lists in a way that minimizes the distance between them and the merged list
+
+    :param a: first list
+
+    :param b: second list
+
+    :param favor_order_of_a: favor order of list `a` over order of list `b`
+
+    :param case_insensitive: merge list in a case-insensitive way
+
+    :return: merged list
+    """
+    a = list(map(repr, a))
+    b = list(map(repr, b))
+
+    # use difflib.Differ (which operates on strings) to find out differences
+    if favor_order_of_a:
+        keys = list(difflib.Differ(linejunk=None).compare(b, a))
+    else:
+        keys = list(difflib.Differ(linejunk=None).compare(a, b))
+
+    # NOTE: change of order are done by removing (-) and adding (+) an entry
+    keys = [ast.literal_eval(k[2:]) for k in keys if k[2:] and k[0] != '?' and (k[0] != '-' or (k[0] == '-' and '+' + k[1:] not in keys))]
+    # unique keys, keep the ordering, allow caseInsensitive
+    if case_insensitive:
+        tmp = [_f.lower() if isinstance(_f, str) else _f for _f in keys]
+        keys = [_f for k, _f in enumerate(keys) if (_f.lower() if isinstance(_f, str) else _f) not in tmp[:k]]
+    else:
+        keys = [_f for k, _f in enumerate(keys) if _f not in keys[:k]]
+    return keys
+
+
 @_available_to_user_util
 def parseLocation(inv):
     """
@@ -1206,7 +1242,17 @@ class SortedDict(dict):
 
     @dynaLoad
     def diff(
-        self, other, ignoreComments=False, ignoreContent=False, skipClasses=(), noloadClasses=(), precision=0.0, order=True, quiet=True
+        self,
+        other,
+        ignoreComments=False,
+        ignoreContent=False,
+        skipClasses=(),
+        noloadClasses=(),
+        precision=0.0,
+        order=True,
+        favor_my_order=False,
+        modify_order=False,
+        quiet=True,
     ):
         """
         Comparison of a SortedDict
@@ -1225,23 +1271,23 @@ class SortedDict(dict):
 
         :param order: does the order of the keys matter
 
+        :param favor_my_order: favor my order of keys
+
+        :param modify_order: update order of input dictionaries based on diff
+
         :param quiet: verbosity of the comparison
 
         :return: comparison dictionary
         """
         # todo: should allow taking differences among any type of dictionary, not only sorted dict
 
-        # use difflib.Differ (which operates on strings) to find out differences
-        selfEntries = [repr(key) for key in list(self.keys())]
-        otherEntries = [repr(key) for key in list(other.keys())]
-        tmp = list(difflib.Differ(linejunk=None).compare(selfEntries, otherEntries))
-        keys = list(map(ast.literal_eval, [_f for _f in [entry[2:] for entry in tmp if entry[0] != '?'] if _f]))
+        # sorted join of self.keys() with other.keys()
+        keys = sorted_join_lists(self.keys(), other.keys(), favor_my_order, self.caseInsensitive or other.caseInsensitive)
 
-        # unique keys, keep the ordering, allow caseInsensitive
-        tmp = SortedDict(caseInsensitive=self.caseInsensitive)
-        for key in keys:
-            tmp[key] = ''
-        keys = list(tmp.keys())
+        # update order of input dictionaries based on diff
+        if modify_order:
+            self.keyOrder = [k for k in keys if k in self.keys()]
+            other.keyOrder = [k for k in keys if k in other.keys()]
 
         if ignoreComments:
             keys = [key for key in keys if not re.match(comment_ptrn, str(key))]
@@ -1273,7 +1319,7 @@ class SortedDict(dict):
                         switch[key] = ['noLoad', False]
                         continue
 
-                if isinstance(self[key], SortedDict) and isinstance(other[key], SortedDict):  # any changes in the subdirs even order
+                if isinstance(self[key], SortedDict) and isinstance(other[key], SortedDict):  # any changes in the subdirs, even order
                     tmp = self[key].diff(
                         other[key],
                         ignoreComments=ignoreComments,
@@ -1281,6 +1327,9 @@ class SortedDict(dict):
                         skipClasses=skipClasses,
                         noloadClasses=noloadClasses,
                         precision=precision,
+                        order=order,
+                        favor_my_order=favor_my_order,
+                        modify_order=modify_order,
                         quiet=quiet,
                     )
                     if np.sum([len(tmp[0][k]) for k in tmp[0]]) or (
@@ -1296,7 +1345,18 @@ class SortedDict(dict):
         return [switch, False, keys]
 
     @dynaLoad
-    def pretty_diff(self, other, ignoreComments=False, ignoreContent=False, skipClasses=(), noloadClasses=(), precision=0.0, quiet=True):
+    def pretty_diff(
+        self,
+        other,
+        ignoreComments=False,
+        ignoreContent=False,
+        skipClasses=(),
+        noloadClasses=(),
+        precision=0.0,
+        order=True,
+        favor_my_order=False,
+        quiet=True,
+    ):
         """
         Comparison of a SortedDict in human readable format
 
@@ -1312,6 +1372,10 @@ class SortedDict(dict):
 
         :param precision: relative precision to which the comparison is carried out
 
+        :param order: does the order of the keys matter
+
+        :param favor_my_order: favor my order of keys
+
         :param quiet: verbosity of the comparison
 
         :return: comparison dictionary in pretty to print format
@@ -1323,6 +1387,8 @@ class SortedDict(dict):
             skipClasses=skipClasses,
             noloadClasses=noloadClasses,
             precision=precision,
+            order=order,
+            favor_my_order=favor_my_order,
             quiet=quiet,
         )
         return pretty_diff(tmp)
